# TODO
# - handle /usr/share/cantata/fonts/fontawesome-4.3.0.ttf
#
# Conditional build:
%bcond_without	udisks	# UDisks support
%bcond_with	musicbrainz	# musicbrainz5

%define		qtver	5.11

Summary:	Music Player Daemon (MPD) graphical client
Name:		cantata
Version:	2.4.2
Release:	1
License:	GPL v2+
Group:		Applications/Multimedia
# https://github.com/CDrummond/cantata/releases
Source0:	https://github.com/CDrummond/cantata/releases/download/v%{version}/%{name}-%{version}.tar.bz2
# Source0-md5:	83b6a2504f1fa40e88d06272aab9f512
Patch0:		%{name}-lrelease.patch
Patch101:	system-qtiocompressor.patch
Patch105:	icons_crash.patch
Patch106:	libdir.patch
URL:		https://github.com/cdrummond/cantata
BuildRequires:	Qt5Concurrent-devel >= %{qtver}
BuildRequires:	Qt5Core-devel >= %{qtver}
BuildRequires:	Qt5DBus-devel >= %{qtver}
BuildRequires:	Qt5Gui-devel >= %{qtver}
BuildRequires:	Qt5IOCompressor-devel
BuildRequires:	Qt5Network-devel >= %{qtver}
BuildRequires:	Qt5Sql-devel >= %{qtver}
BuildRequires:	Qt5Svg-devel >= %{qtver}
BuildRequires:	Qt5Widgets-devel >= %{qtver}
BuildRequires:	Qt5Xml-devel >= %{qtver}
BuildRequires:	avahi-devel
BuildRequires:	cmake >= 2.6
BuildRequires:	desktop-file-utils
BuildRequires:	libcddb-devel
BuildRequires:	libcdio-paranoia-devel
BuildRequires:	libmtp-devel >= 1.1.0
%{?with_musicbrainz:BuildRequires:	libmusicbrainz5-devel}
# C++11
BuildRequires:	libstdc++-devel >= 6:4.7
BuildRequires:	media-player-info
BuildRequires:	pkgconfig
BuildRequires:	qt5-build >= %{qtver}
BuildRequires:	qt5-linguist >= %{qtver}
BuildRequires:	qt5-qmake >= %{qtver}
BuildRequires:	rpmbuild(find_lang) >= 1.37
BuildRequires:	rpmbuild(macros) >= 1.596
BuildRequires:	systemd-devel
BuildRequires:	taglib-devel >= 1.6
BuildRequires:	vlc-devel
BuildRequires:	zlib-devel
Requires:	Qt5Concurrent >= %{qtver}
Requires:	Qt5Core >= %{qtver}
Requires:	Qt5DBus >= %{qtver}
Requires:	Qt5Gui >= %{qtver}
Requires:	Qt5Network >= %{qtver}
Requires:	Qt5Sql >= %{qtver}
Requires:	Qt5Sql-sqldriver-sqlite3 >= %{qtver}
Requires:	Qt5Svg >= %{qtver}
Requires:	Qt5Widgets >= %{qtver}
Requires:	Qt5Xml >= %{qtver}
Requires:	gtk-update-icon-cache
Requires:	hicolor-icon-theme
Requires:	libmtp >= 1.1.0
Requires:	media-player-info
Requires:	taglib >= 1.6
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Cantata is a graphical client for the music player daemon (MPD).

Features:
- Multiple MPD collections.
- Highly customisable layout.
- Songs grouped by album in play queue.
- Context view to show artist, album, and song information of current
  track.
- Simple tag editor.
- File organizer - use tags to organize files and folders.
- Ability to calculate ReplyGain tags.
- Dynamic playlists.
- Online services; Jamendo, Magnatune, SoundCloud, and Podcasts.
- Radio stream support - with the ability to search for streams via
  TuneIn and ShoutCast.
- USB-Mass-Storage and MTP device support.
- Audio CD ripping and playback.
- Playback of non-MPD songs, via simple in-built HTTP server.
- MPRISv2 DBUS interface.
- Support for KDE global shortcuts (KDE builds), GNOME media keys, and
  generic media keys (via Qxt support)
- Ubuntu/ambiance theme integration.

%prep
%setup -q
%patch0 -p1

%patch101 -p1
rm -rfv 3rdparty/{qjson,qtiocompressor}

rm -rfv 3rdparty/{qtsingleapplication,qxt}
sed -i.system-qxt-headers -e 's|^#include "qxt/qxtglobalshortcut.h"|#include <QxtGlobalShortcut>|g' \
	gui/qxtmediakeys.cpp

#%patch105 -p1
%patch106 -p1

%build
install -d build
cd build
CXXFLAGS="%{rpmcxxflags} -I/usr/include/qt5/QtSolutions"
%cmake \
	-DCANTATA_HELPERS_LIB_DIR=%{_lib} \
	-DENABLE_FFMPEG:BOOL=OFF \
	-DENABLE_LIBVLC=ON \
	-DENABLE_MPG123:BOOL=OFF \
	-DENABLE_MUSICBRAINZ=%{?with_musicbrainz:ON}%{!?with_musicbrainz:OFF} \
	-DENABLE_UDISKS2:BOOL=%{?with_udisks:ON}%{!?with_udisks:OFF} \
	..

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install/fast -C build \
	DESTDIR=$RPM_BUILD_ROOT

%find_lang %{name} --with-qm

desktop-file-validate $RPM_BUILD_ROOT%{_desktopdir}/cantata.desktop

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_desktop_database
%update_icon_cache hicolor

%postun
%update_desktop_database
%update_icon_cache hicolor

%files -f %{name}.lang
%defattr(644,root,root,755)
%doc AUTHORS ChangeLog LICENSE README TODO
%attr(755,root,root) %{_bindir}/cantata
%dir %{_libdir}/%{name}
%attr(755,root,root) %{_libdir}/%{name}/cantata-tags
%{_desktopdir}/cantata.desktop
%{_iconsdir}/hicolor/*/*/*.png
%{_iconsdir}/hicolor/*/*/*.svg
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
#%{_datadir}/%{name}/config
%{_datadir}/%{name}/icons
#%{_datadir}/%{name}/mpd
%{_datadir}/%{name}/scripts
#%{_datadir}/%{name}/themes
%changelog
* Thu Jan 21 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/cantata.git;a=log;h=master

* Thu Jan 21 2021 Jan Palus <atler@pld-linux.org> d6c8e6d
- take lrelease path from cmake config

* Thu Jan 21 2021 Jan Palus <atler@pld-linux.org> 99c363d
- up to 2.4.2

* Thu Jan 21 2021 Jan Palus <atler@pld-linux.org> 847bbe7
- drop unused flags

* Thu Jan 21 2021 Jan Palus <atler@pld-linux.org> 0af242b
- kde4/qt4 stuff dropped by upstream in 2.1.0

* Thu Jan 21 2021 Jan Palus <atler@pld-linux.org> e082386
- xcb platform plugin is not required

* Mon Mar 02 2020 Jan Palus <atler@pld-linux.org> e3d58df
- up to 2.4.1

* Sun Sep 18 2016 Jan Palus <atler@pld-linux.org> 29009a6
- R: Qt5Sql-sqldriver-sqlite3

* Tue Jul 12 2016 Elan Ruusamäe <glen@delfi.ee> e800399
- up to 2.0.1

* Tue Jul 12 2016 Elan Ruusamäe <glen@delfi.ee> ed68180
- fix cmake warning

* Mon Jan 11 2016 Jan Rękorajski <baggins@pld-linux.org> 793fa06
- apply libdir fix
- rel 4

* Mon Jan 11 2016 Jan Rękorajski <baggins@pld-linux.org> 9b2ce91
- fix cmake so it actually uses what's passed in CANTATA_HELPERS_LIB_DIR
- rel 3

* Wed Jan 06 2016 Elan Ruusamäe <glen@delfi.ee> 9bb82db
- always have oxygen theme, for now

* Sun Jan 03 2016 Elan Ruusamäe <glen@delfi.ee> 2c1706e
- BR qt5-linguist

* Sun Jan 03 2016 Elan Ruusamäe <glen@delfi.ee> 224efb2
- install translations

* Sun Jan 03 2016 Elan Ruusamäe <glen@delfi.ee> a121a47
- link with qt5 version

* Sun Jan 03 2016 Elan Ruusamäe <glen@delfi.ee> 0c2d410
- fix cantata-tags execute attrs

* Sun Jan 03 2016 Elan Ruusamäe <glen@delfi.ee> db3617e
- typo in bcond name

* Fri Jan 01 2016 Elan Ruusamäe <glen@delfi.ee> 1e9b33f
- cleanup qt4

* Thu Dec 31 2015 Elan Ruusamäe <glen@delfi.ee> d300b44
- rel 1

* Tue Dec 29 2015 Elan Ruusamäe <glen@delfi.ee> 120648c
- require Qt5Gui-platform-xcb

